from . import utils

class Client:
    def __init__(self, password: str):
        self.password = password
        
    def encrypt(self, string: str):
        return utils.encryptkit(string, self.password)
    
    def decrypt(self, string: str):
        return utils.decryptkit(string, self.password)


class InvalidPasswordException(Exception):
    """
    Exception raised if password provided is incorrect.
    """
    def __init__(self, message: str):
        self.message = message
        super().__init__(self.message)
        
class UserAlreadyExists(Exception):
    """
    Exception raised if user already exists in directory.
    """
    def __init__(self, message: str):
        self.message = message
        super().__init__(self.message)
        
class InvalidUser(Exception):
    """
    Exception raised if user does not exist in a directory.
    """
    def __init__(self, message: str):
        self.message = message
        super().__init__(self.message)